<?php

namespace Drupal\issuu_viewer\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a default Issuu viewer widget.
 *
 * @FieldWidget(
 *   id = "issuu_viewer_default",
 *   label = @Translation("Issuu viewer"),
 *   field_types = {
 *     "issuu_viewer_document_id"
 *   },
 * )
 */
class IssuuViewerDefaultWidget extends WidgetBase {

  /**
   * Indicator for rendering Issuu embed.
   */
  const ISSUU_EMBED = 0;

  /**
   * Indicator for rendering legacy Issuu embed.
   */
  const LEGACY_ISSUU_EMBED = 1;

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $options = [
      static::ISSUU_EMBED => $this->t('Issuu embed'),
      static::LEGACY_ISSUU_EMBED => $this->t('legacy Issuu embed'),
    ];

    $element['value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Document ID'),
      '#default_value' => $items[$delta]->value,
      '#description' => $this->t('The reference to the embedded document.'),
    ];

    $element['view_mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('View mode'),
      '#options' => $options,
      '#default_value' => $items[$delta]->view_mode,
      '#description' => $this->t('The view mode of rendering the Issuu embed.'),
    ];

    $element += [
      '#type' => 'fieldset',
    ];

    return $element;
  }

}
